@@ -1,5 +1,6 @@
 """This module includes Normalizer and NormalizerBuilder"""
 from .normalizer import Normalizer
 from .normalizer_builder import NormalizerBuilder
+from .nltk_tokenizer import NltkTokenizer
 
-__all__ = ["Normalizer", "NormalizerBuilder"]
+__all__ = ["Normalizer", "NormalizerBuilder", "NltkTokenizer"]
